betty.gui.window module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui.window module

Manage windows.

class betty.gui.window.BettyMainWindow

  Bases: `LocalizedObject`, `QMainWindow`

  A generic window.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  __init__(app: betty.app.App, *, parent: PyQt6.QtCore.QObject | None = None)
    Parameters:

      - app (`betty.app.App`)

      - parent (`PyQt6.QtCore.QObject` | `None`)

  close() → bool
    Return type:

      `bool`

  window_height = 600

    The window’s default height in pixels.

  property window_title: Localizable

    The human-readable short title of this window.

  window_width = 800

    The window’s default width in pixels.